
Changelog
=========

0.0.3 (2021-1-8)
------------------

* cli get subcommands and produce meaningful results
* robustness about error handling
* Testing and documentation

0.0.2 (2021-1-4)
------------------

* Improved cli (first functional).

0.0.1 (2020-12-19)
------------------

* First release on PyPI.
